import{cG as r}from"./outputWidgets.cf5b7366.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="5a38dbd7-54ef-429b-bef2-33a61791d8a3",e._sentryDebugIdIdentifier="sentry-dbid-5a38dbd7-54ef-429b-bef2-33a61791d8a3")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.2372f0ce.js.map
