import"./outputWidgets.cf5b7366.js";import{M as r}from"./Title.adce1298.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e0c96c57-7417-4355-8d74-400ddba62542",e._sentryDebugIdIdentifier="sentry-dbid-e0c96c57-7417-4355-8d74-400ddba62542")}catch{}})();function o(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:o(n)}));default:return[{title:e,key:e}]}}function s(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{s as a,o as t};
//# sourceMappingURL=ant-design.55c856ad.js.map
