import{d as u,eA as b,J as f,b as y,c as g,u as _}from"./outputWidgets.cf5b7366.js";import{a as w}from"./asyncComputed.2caa7fe6.js";import"./router.565b4739.js";import{M as n}from"./member.732dd784.js";import"./index.2fa55c7c.js";import{C as I}from"./CrudView.ca1846b4.js";import"./Title.adce1298.js";import"./index.3d2fbf9e.js";import"./gateway.409ff644.js";import"./activeRecord.f30e02c2.js";import"./pubsub.664a70af.js";import"./icons.c510a141.js";import"./index.7622dd54.js";import"./Form.c8affe88.js";import"./url.fb40e08c.js";import"./index.47f17eed.js";import"./index.aee8b5d5.js";import"./index.9583d9e9.js";import"./index.10cdfb2c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f22ea7b3-329c-45d7-8a80-3c59e20b1f58",e._sentryDebugIdIdentifier="sentry-dbid-f22ea7b3-329c-45d7-8a80-3c59e20b1f58")}catch{}})();const F=u({__name:"Members",setup(e){const r=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.db9e19b5.js.map
