import{M as a}from"./Modal.d2e187f0.js";import{d as r,H as c,r as d,a as _,b as l,et as f,f as n,w as i,bg as m,e as u,x as b}from"./outputWidgets.cf5b7366.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c4151d66-8bb1-4c0a-8ab5-a34c83431481",e._sentryDebugIdIdentifier="sentry-dbid-c4151d66-8bb1-4c0a-8ab5-a34c83431481")}catch{}})();const p=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,w)=>{const s=_("router-view");return l(),f(m,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=b(y,[["__scopeId","data-v-7e290e34"]]);export{I as default};
//# sourceMappingURL=Home.798433d4.js.map
