import{C as n,A as d}from"./CollapsePanel.38c8849b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ea7ef7cc-addc-47dd-8175-f3ac6dfb2da0",e._sentryDebugIdIdentifier="sentry-dbid-ea7ef7cc-addc-47dd-8175-f3ac6dfb2da0")}catch{}})();n.Panel=d;n.install=function(e){return e.component(n.name,n),e.component(d.name,d),e};
//# sourceMappingURL=index.98a18e7b.js.map
