import{x as t,b as s,et as o}from"./outputWidgets.cf5b7366.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9e88e251-735f-401b-ae69-250fb20e34d5",e._sentryDebugIdIdentifier="sentry-dbid-9e88e251-735f-401b-ae69-250fb20e34d5")}catch{}})();const r={},i={class:"organization-settings"};function a(e,n){return s(),o("div",i,"Organization settings")}const c=t(r,[["render",a]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.449b5ccb.js.map
