import{W as s}from"./outputWidgets.cf5b7366.js";import{c as i,d as c}from"./index.50be7881.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="ded71476-b082-45a8-966f-e7593f93275d",e._sentryDebugIdIdentifier="sentry-dbid-ded71476-b082-45a8-966f-e7593f93275d")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:a}=i(c),b=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{b as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.a620d27a.js.map
