import{R as n}from"./Title.adce1298.js";import{F as f}from"./outputWidgets.cf5b7366.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="118147e0-4f28-404e-8203-2ff430b8da95",e._sentryDebugIdIdentifier="sentry-dbid-118147e0-4f28-404e-8203-2ff430b8da95")}catch{}})();const s=f(n);export{s as A};
//# sourceMappingURL=index.aee8b5d5.js.map
