import"./outputWidgets.cf5b7366.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="47072605-e2b2-4009-9437-0e0f19499b77",e._sentryDebugIdIdentifier="sentry-dbid-47072605-e2b2-4009-9437-0e0f19499b77")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.fb40e08c.js.map
