import{d as r,r as c,o as l,eQ as d,b as u,et as f,eC as p,eO as y}from"./outputWidgets.cf5b7366.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="97241aa2-c610-4863-9321-bc579a818c04",e._sentryDebugIdIdentifier="sentry-dbid-97241aa2-c610-4863-9321-bc579a818c04")}catch{}})();const m=r({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=c(null);return l(()=>{s.value&&o.action.setElement(s.value),d.addAction(o.action)}),(a,t)=>(u(),f("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=i=>n("click")),onKeydown:t[1]||(t[1]=y(i=>n("click"),["enter"]))},p(a.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.c820a0dc.js.map
