import{S as c}from"./Sidebar.c4807110.js";import{_ as d}from"./Navbar.vue_vue_type_script_setup_true_lang.0e12044d.js";import{G as p,H as l,I as u}from"./icons.c510a141.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.cf5b7366.js";import{a as w}from"./asyncComputed.2caa7fe6.js";import"./router.565b4739.js";import{O as z}from"./organization.4a30a51b.js";import"./index.2fa55c7c.js";import{B as h}from"./BaseLayout.03efcbf5.js";import"./Tooltip.5cf131eb.js";import"./logo.084e5d7c.js";import"./index.7622dd54.js";import"./Title.adce1298.js";import"./index.10cdfb2c.js";import"./index.21604c00.js";import"./index.3d2fbf9e.js";import"./gateway.409ff644.js";import"./activeRecord.f30e02c2.js";import"./pubsub.664a70af.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="76f1198c-e4cb-4e85-afdd-f80c87d93bdd",e._sentryDebugIdIdentifier="sentry-dbid-76f1198c-e4cb-4e85-afdd-f80c87d93bdd")}catch{}})();const q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(d,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.b2d7745b.js.map
