import{x as o,a,b as i,c,g as p,h as d,_,i as u,T as l,j as f,P as h,C as b,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.cf5b7366.js";import{u as k}from"./index.e4f20c17.js";import"./pubsub.664a70af.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7bb3e7c9-11a3-4fb7-9d23-54727fc84c25",e._sentryDebugIdIdentifier="sentry-dbid-7bb3e7c9-11a3-4fb7-9d23-54727fc84c25")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.d06ea71e.js"),["assets/Player.d06ea71e.js","assets/index.3d2fbf9e.js","assets/outputWidgets.cf5b7366.js","assets/outputWidgets.e6401203.css","assets/uuid.8fd92523.js","assets/broker.366e247c.js","assets/index.e4f20c17.js","assets/pubsub.664a70af.js","assets/executeJs.cf9bd84e.js","assets/icons.c510a141.js","assets/CircularLoading.832431bd.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.bb557329.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.193c982b.js","assets/Steps.998aa76d.css","assets/Modal.d2e187f0.js","assets/Modal.5aaf8eba.css","assets/executeJs.dfa3b35d.css","assets/WidgetsFrame.9f056f5d.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.c820a0dc.js","assets/broker.ac4594bd.css","assets/DashPlayer.60ce78e2.js","assets/geometryUtils.218a0963.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.2caa7fe6.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),f(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.1ab215d4.js.map
